import { hoverTooltip } from "@codemirror/view";
import { getHover } from "./getHover.js";
import { defaultRenderer } from "./renderTooltip.js";
import { tsFacet } from "../facet/tsFacet.js";
/**
 * This binds the CodeMirror `hoverTooltip` method
 * with a code that pulls types and documentation
 * from the TypeScript environment.
 */
export function tsHover({ renderTooltip = defaultRenderer, } = {}) {
    return hoverTooltip(async (view, pos) => {
        const config = view.state.facet(tsFacet);
        if (!config)
            return null;
        const hoverData = getHover({
            ...config,
            pos,
        });
        if (!hoverData)
            return null;
        return {
            pos: hoverData.start,
            end: hoverData.end,
            create: () => renderTooltip(hoverData, view),
        };
    });
}
//# sourceMappingURL=tsHover.js.map